<li class="item">
    {% if instance.get_link %}<a href="{{ instance.get_link }}"{% if instance.target %} target="{{ instance.target }}"{% endif %}>{% endif %}
    {% if image %}<img src="{{ image.url }}" alt="" />{% endif %}
    {% if instance.get_link %}</a>{% endif %}
    {% if instance.content %}
    <div class="item-content">
        {{ instance.content|safe }}
    </div>
    {% endif %}
</li>